Check for users who pasted the example code but didn't add an API key
Source:R/user_validation_helpers.R
check_for_default_APIs.RdCheck for users who pasted the example code but didn't add an API key
Usage
check_for_default_APIs(
hf.token,
groq.API = NULL,
openai.API,
anthropic.API = NULL,
jina.API = NULL
)