Validate and Clean item.examples Against Cleaned items.attributes
Source: R/user_validation_helpers.R
item.examples_validate.RdEnsures item.examples is a data frame with required string columns and that the values
in type and attribute align with the cleaned structure of items.attributes.
Returns a cleaned version of the data frame with normalized values:
typeandattributeare trimmed and lowercasedstatementis trimmed (case preserved)