Check that the run.overall and all.together flags are logically consistent with the number of item types.
Source: R/user_validation_helpers.R
run_flags_validate.RdCheck that the run.overall and all.together flags are logically consistent with the number of item types.